# HDF5_BLS

**HDF5_BLS** is a Python library for handling Brillouin Light Scattering (BLS) data and converting it into a standardized HDF5 format. The library provides functions to open raw data files, define and import abscissa, add metadata, and save the organized data in HDF5 files.
The library is currently compatible with the following file formats:
- "*.DAT" files: spectra returned by the GHOST software
- "*.TIF" files: an image format that can be used to export 2D detector images.

## Installation

You can install **HDF5_BLS** directly from PyPI:

```bash
pip install HDF5_BLS
```

## Documentation

A full documentation is accessible at [this link](https://hdf5-bls.readthedocs.io/en/latest/)

## Contributing

Pull requests are welcome. For major changes, please open an issue first
to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License

[MIT](https://choosealicense.com/licenses/mit/)